translate.storage.oo.unormalizechar

Package translate :: Package storage :: Module oo :: Class unormalizechar |
[hide private]
[frames] | no frames]

# Class unormalizechar

source code

Instance Methods | [hide private]
    new empty dictionary
__init__(self, normalchars) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
__getitem__(self, key) x[y] | source code
Inherited from `dict`: `__cmp__`, `__contains__`, `__delitem__`, `__eq__`, `__ge__`, `__getattribute__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__ne__`, `__new__`, `__repr__`, `__setitem__`, `__sizeof__`, `clear`, `copy`, `fromkeys`, `get`, `has_key`, `items`, `iteritems`, `iterkeys`, `itervalues`, `keys`, `pop`, `popitem`, `setdefault`, `update`, `values` Inherited from `object`: `__delattr__`, `__format__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `dict`: `__hash__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, normalchars) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Returns:
    new empty dictionary
Overrides: object.__init__ (inherited documentation)

### __getitem__(self, key) (Indexing operator) | source code
x[y] Overrides: dict.__getitem__ (inherited documentation)